@@ -3,10 +3,10 @@ import os
 import sys
 import logging
 from argparse import ArgumentParser
-from traceback import format_exc
 
 import exonwebui
-from exonutils.webapp import BaseWebSrv
+from exonutils.webapp.server import SimpleWebServer
+
 from views import MenuBoardView
 
 logging.basicConfig(
@@ -16,7 +16,17 @@ logging.addLevelName(logging.WARNING, "WARN")
 logging.addLevelName(logging.CRITICAL, "FATAL")
 
 
-if __name__ == '__main__':
+HOST = "0.0.0.0"
+PORT = 8000
+
+APP_OPTIONS = {
+    'secret_key': "0123456789ABCDEF",
+    'max_content_length': 10485760,  # 10MiB
+    'templates_auto_reload': False,
+}
+
+
+def main():
     logger = logging.getLogger()
     logger.name = 'main'
 
@@ -32,7 +42,9 @@ if __name__ == '__main__':
         args = pr.parse_args()
 
         if args.debug > 0:
-            logging.getLogger().setLevel(logging.DEBUG)
+            logger.setLevel(logging.DEBUG)
+        if args.debug >= 3:
+            APP_OPTIONS['templates_auto_reload'] = True
 
         # adjust resources links
         base_path = os.path.abspath(os.path.dirname(__file__))
@@ -45,19 +57,24 @@ if __name__ == '__main__':
             if os.path.exists(src_dir):
                 os.symlink(src_dir, link_path)
 
-        cfg = {
-            'secret_key': "0123456789ABCDEF",
-            'max_content_length': 10485760,
-            'templates_auto_reload': bool(args.debug > 0),
-        }
+        websrv = SimpleWebServer(
+            name='WebUiPortal', options=APP_OPTIONS,
+            logger=logger, reqlogger=reqlog)
+        websrv.base_path = base_path
+        websrv.initialize()
 
-        webapp = BaseWebSrv(
-            'SampleWebui', options=cfg, logger=logger, debug=args.debug)
-        webapp.base_path = base_path
-        webapp.initialize()
-        webapp.load_views(MenuBoardView.__subclasses__())
-        webapp.start('0.0.0.0', 8000)
+        for view_cls in MenuBoardView.__subclasses__():
+            websrv.add_view(view_cls())
 
-    except Exception:
-        logger.fatal(format_exc())
+        websrv.start(
+            HOST, PORT,
+            debug=bool(args.debug >= 1),
+            use_reloader=bool(args.debug >= 3))
+
+    except Exception as e:
+        logger.fatal(str(e), exc_info=args.debug)
         sys.exit(1)
+
+
+if __name__ == '__main__':
+    main()
